@@ -15,6 +15,8 @@ from Bio.PDB.Residue import Residue
 from Bio.PDB.NeighborSearch import NeighborSearch
 from Bio.PDB.vectors import Vector, rotaxis
 
+from biobb_structure_checking.constants import MSGS
+
 #chain types
 PROTEIN = 1
 DNA = 2
@@ -303,7 +305,7 @@ def check_chiral(res, at1, at2, at3, at4, sign=1.):
     for atm in (at1, at2, at3, at4):
         at_ok = at_ok and atm in res
         if not at_ok:
-            print('Warning: atom {:3} not found in {}'.format(atm, residue_id(res)))
+            print(MSGS['ATOM_NOT_FOUND'].format(atm, residue_id(res)))
     if at_ok:
         vec1 = res[at1].coord - res[at2].coord
         vec2 = res[at3].coord - res[at2].coord
@@ -474,7 +476,7 @@ def get_backbone_links(struc, backbone_atoms, covlnk, join_models=True):
                         and (join_models or same_model(at1.get_parent(), at2.get_parent())):
                     cov_links.append(sorted([at1, at2], key=lambda x: x.serial_number))
         else:
-            print("Warning: No backbone atoms defined")
+            print(MSGS['NO_BACKBONE_ATOMS'])
 
     return cov_links
 
@@ -559,15 +561,17 @@ def add_hydrogens_backbone(res, prev_res, next_res):
     """ Add hydrogen atoms to the backbone"""
 
     # only proteins
+    rcode = res.get_resname()
 
-    if not _protein_residue_check(res.get_resname()):
-        return "Warning: Residue not valid in this context "
+    if not _protein_residue_check(rcode):
+        return MSGS['RESIDUE_NOT_VALID']
 
-    error_msg = "Warning: not enough atoms to build backbone hydrogen atoms on"
+    error_msg = MSGS['NOT_ENOUGH_ATOMS'].format('backbone')
 
     if res.get_resname() not in ('ACE', 'NME'):
         if 'N' not in res:
             return error_msg
+
     if 'CA' not in res:
         return error_msg
 
@@ -576,12 +580,10 @@ def add_hydrogens_backbone(res, prev_res, next_res):
         if res.get_resname() == 'PRO':
             if 'CD' not in res:
                 return error_msg
+            crs = build_coords_2xSP3(HDIS, res['N'], res['CA'], res['CD'])
+            add_new_atom_to_residue(res, 'H2', crs[0])
+            add_new_atom_to_residue(res, 'H3', crs[1])
 
-            add_new_atom_to_residue(
-                res,
-                'H',
-                build_coords_SP2(HDIS, res['N'], res['CA'], res['CD'])
-            )
         elif res.get_resname() == 'ACE':
             crs = build_coords_3xSP3(HDIS, res['CA'], next_res['N'], res['C'])
             add_new_atom_to_residue(res, 'HA1', crs[0])
@@ -596,7 +598,7 @@ def add_hydrogens_backbone(res, prev_res, next_res):
             add_new_atom_to_residue(res, 'H1', crs[0])
             add_new_atom_to_residue(res, 'H2', crs[1])
             add_new_atom_to_residue(res, 'H3', crs[2])
-
+            res.resname = 'N' + res.resname
 
     elif res.get_resname() != 'PRO':
         if 'C' not in prev_res:
@@ -608,7 +610,7 @@ def add_hydrogens_backbone(res, prev_res, next_res):
             build_coords_SP2(HDIS, res['N'], res['CA'], prev_res['C'])
         )
 
-    if res.get_resname() == 'GLY':
+    if res.get_resname() in ['GLY', 'NGLY']:
         if 'C' not in res:
             return error_msg
 
@@ -636,12 +638,16 @@ def add_hydrogens_backbone(res, prev_res, next_res):
 
 def add_hydrogens_side(res, res_library, opt, rules):
     """ Add hydrogens to side chains"""
-    if res.get_resname() in ('ACE', 'NME', 'GLY'):
+
+    if res.get_resname() in ('ACE', 'NME', 'GLY', 'NGLY', 'CGLY'):
         return False
+
     if 'N' not in res or 'CA' not in res or 'C' not in res:
-        return "Warning: not enough atoms to build side chain hydrogen atoms on"
+        return MSGS['NOT_ENOUGH_ATOMS'].format('side')
+
     for key_rule in rules.keys():
         rule = rules[key_rule]
+
         if rule['mode'] == 'B2':
             crs = build_coords_2xSP3(
                 rule['dist'],
